'use strict'
/* admin/del.js
 * routes for intra-server peer sharing
*/
 
const env = require(process.argv[2]||'../env.json')
const fs = require('fs').promises

// Get secret
const local_secret = env.SERVERS.filter(
	(server) => server.host === env.LOCAL_SERVER
)[0].secret

module.exports = async (req, res) => {
	console.log(`Received delete from ${req.requester} for ${req.body}`)
	let config

	// Check secret
	if (req.query['secret']!==local_secret) {
		console.log(`Peer sent from ${req.requester} without correct secret querystring!`)
		return res.sendStatus(403)
	}
		
	// Read config file
	else try {
		const config_file = await fs.readFile(env.WG_CONFIG_FILE)
		config = config_file.toString()
	}
	catch (err) {
		console.error(`Failed to load config from ${env.WG_CONFIG_FILE}:\n`,err)
		res.sendStatus(500)
	}
		
	// Find peer in config
	const peer = config.split('\n\n')
	.filter( (paragraph) => {
		return paragraph.includes('[Peer]')
	}).filter( (peer) => {
		return peer.includes(`PublicKey = ${req.body}`)
	})
	
	// Delete peer
	try { await fs.writeFile(env.WG_CONFIG_FILE, 
		config.replace(`\n\n${peer}`,'')
		.replace('\n\n\n','\n\n')
	) }
	catch (err) { 
		console.error(`Failed to delete peer config from ${env.WG_CONFIG_FILE}:\n`,err)
		return res.sendStatus(500)
	}
		
	// Success
	console.log(`Deleted peer by requested from ${req.requester}`)
	return res.sendStatus(200)
	
}