'use strict'
const env = require(process.argv[2]||'../env.json')

// Get DNS Servers in a string for peer configs
let DNS_SERVERS = []
let SERVER_IPS = []
for (const server of env.SERVERS) {
	if (server.ipv4) {
		SERVER_IPS.push(server.ipv4)
		if (server.dns) DNS_SERVERS.push(server.ipv4)
	}
	if (server.ipv6) {
		SERVER_IPS.push(server.ipv6)
		if (server.dns) DNS_SERVERS.push(server.ipv6)
	}
}
const DNS_SERVERS_STRING = DNS_SERVERS.join(', ')


// Actual middleware
// These functions run every request so keep them lean
module.exports = {
	
	getDnsServers: (req,res,next) => {
		res.locals.DNS_SERVERS_STRING = DNS_SERVERS_STRING
		next()
	},
	
	getRequester: (env.ENV==='prod')?
		(req, res, next) => {
			req.requester = req.headers['x-forwarded-for'] || req.ip.replace('::ffff:','')
			next()
		}:
		(req, res, next) => {
			req.requester = env.TEST_REQUESTER
			next()
		},
		
	getAdminRequester: (env.ENV==='prod')?
		(req, res, next) => {
			req.requester = req.ip.replace('::ffff:','')
			next()
		}:
		(req, res, next) => {
			req.requester = env.TEST_ADMIN
			next()
		},
	
	// Block clients, only allow servers (for intra-server peer sharing)
	allowServers: (req, res, next) => {
		if (SERVER_IPS.includes(req.requester)) next()
		else {
			console.log(`Rejected request to ${req.path} from ${req.requester} not in SERVER_IPS`)
			res.sendStatus(403)
		}
	},
	
}