'use strict'
/* index.js
 * Entrypoint and server listener
*/

const env = require(process.argv[2]||'./env.json')
const mw = require('./includes/middleware.js')
const express = require('express')
const fs = require('fs').promises
const app = express()
const admin = express()

// Check the wireguard config file for '::'
;(async (f) => {
	let config; try {
		config = (await fs.readFile(f)).toString()
	} catch (err) {
		console.error(`Failed to read ${f}!`)
		if (err) console.error(err.message)
	}
	if (config.includes('::'))
		console.error(`Found double colons (::) in ${f}!  Please expand all IPv6 addresses to prevent parsing issues!`)
})(env.WG_CONFIG_FILE)

app.set('trust proxy', true)
	.use(mw.getRequester)
	.get('/', (req, res) => res.redirect('/list'))
	.get('/list', require('./app/list.js'))
	.get('/add', mw.getDnsServers, require('./app/add.js'))
	.get('/del', require('./app/del.js'))
	.listen(env.PORT)
	
admin.set('trust proxy', true)
	.use(mw.getAdminRequester)
	.use(mw.allowServers)
	.use(express.text())
	.post('/add', require('./admin/add.js'))
	.post('/del', require('./admin/del.js'))
	.listen(env.ADMIN_PORT)
	
console.log('Server started')